require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "Formatter" do

  # "1s 0ms"


  describe "progressive output" do

    it "should output only millis if zero" do
      duration = TickTock::Duration.new(0)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "0ms"
    end

    it "should output millis" do
      duration = TickTock::Duration.new(1)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1ms"
    end

    it "should output only millis if less than second" do
      duration = TickTock::Duration.new(999)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "999ms"
    end

    it "should output seconds and millis if exactly 1 second" do
      duration = TickTock::Duration.new(1000)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1s 0ms"
    end

    it "should output seconds and millis only up to 1 minute" do
      duration = TickTock::Duration.new(59999)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "59s 999ms"
    end

    it "should output minutes, seconds, and millis at exactly 1 minute" do
      duration = TickTock::Duration.new(60000)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1m 0s 0ms"
    end

    it "should output minutes, seconds, and millis up to 1 hour" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_HOUR - 1)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "59m 59s 999ms"
    end

    it "should output hours, minutes, seconds, and millis at exactly hour" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_HOUR)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1h 0m 0s 0ms"
    end

    it "should output hours, minutes, seconds, and millis up to 1 day" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_DAY - 1)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "23h 59m 59s 999ms"
    end

    it "should output days, hours, minutes, seconds, and millis at exactly 1 day" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_DAY)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1d 0h 0m 0s 0ms"
    end

    it "should output days, hours, minutes, seconds, and millis up to 1 week" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_WEEK - 1)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "6d 23h 59m 59s 999ms"
    end

    it "should output weeks, days, hours, minutes, seconds, and millis at exactly 1 week" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_WEEK)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1w 0d 0h 0m 0s 0ms"
    end

    it "should output weeks, days, hours, minutes, seconds, and millis up to 1 year" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_YEAR - 1)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "51w 6d 23h 59m 59s 999ms"
    end

    it "should output years, weeks, days, hours, minutes, seconds, and millis at exactly 1 year" do
      duration = TickTock::Duration.new(TickTock::Duration::MILLIS_IN_YEAR)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "1y 0w 0d 0h 0m 0s 0ms"
    end

    it "should output years, weeks, days, hours, minutes, seconds, and millis for a long time" do
      duration = TickTock::Duration.new((TickTock::Duration::MILLIS_IN_YEAR * 10000) +
                                        (TickTock::Duration::MILLIS_IN_WEEK * 12) +
                                        (TickTock::Duration::MILLIS_IN_DAY * 5) +
                                        (TickTock::Duration::MILLIS_IN_HOUR * 13) +
                                        (TickTock::Duration::MILLIS_IN_MINUTE * 14) +
                                        (TickTock::Duration::MILLIS_IN_SECOND * 7) + 18)
      formatter = TickTock::Formatter.new(duration)
      formatter.to_s.should == "10000y 12w 5d 13h 14m 7s 18ms"
    end

  end

end